Documentation
¶
Overview ¶
Package server implements the server initialization for the api.apihttp and balloon tree structure against a storage engine.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( QedSenderInstancesCount = prometheus.NewGauge( prometheus.GaugeOpts{ Name: "qed_sender_instances_count", Help: "Number of sender agents running", }, ) QedSenderBatchesSentTotal = prometheus.NewCounter( prometheus.CounterOpts{ Name: "qed_sender_batches_sent_total", Help: "Number of batches sent by the sender.", }, ) )
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
//Log level
Log string
// Unique identifier to allow connections
APIKey string
// Unique name for this node. It identifies itself both in raft and
// gossip clusters. If not set, fallback to hostname.
NodeID string
// TLS server bind address/port.
HTTPAddr string
// Raft communication bind address/port.
RaftAddr string
// Raft management server bind address/port. Useful to join the cluster
// and get cluster information.
MgmtAddr string
// Metrics bind address/port.
MetricsAddr string
// List of raft nodes, through which a cluster can be joined
// (protocol://host:port).
RaftJoinAddr []string
// Path to storage directory.
DBPath string
// Path to Raft storage directory.
RaftPath string
// Gossip management server bind address/port.
GossipAddr string
// List of nodes, through which a gossip cluster can be joined (protocol://host:port).
GossipJoinAddr []string
// Path to the private key file used to sign snapshots.
PrivateKeyPath string
// Enable TLS service
EnableTLS bool
// Enable Pprof prifiling server
EnableProfiling bool
// Profiling server address/port
ProfilingAddr string
// TLS server cerificate
SSLCertificate string
// TLS server cerificate key
SSLCertificateKey string
// DB WAL TTL
DbWalTtl time.Duration
}
func DefaultConfig ¶
func DefaultConfig() *Config
type Sender ¶
type Sender struct {
Interval time.Duration
BatchSize int
NumSenders int
TTL int
// contains filtered or unexported fields
}
func (Sender) RegisterMetrics ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server encapsulates the data and login to start/stop a QED server
func (*Server) RegisterMetrics ¶
Click to show internal directories.
Click to hide internal directories.